cfg.c (check_bb_profile): Fix typos.
authorDiego Novillo <dnovillo@redhat.com>
Tue, 24 Aug 2004 01:13:01 +0000 (01:13 +0000)
committerDiego Novillo <dnovillo@gcc.gnu.org>
Tue, 24 Aug 2004 01:13:01 +0000 (21:13 -0400)
* cfg.c (check_bb_profile): Fix typos.
* function.c (assign_parm_is_stack_parm): Likewise.
* tree-nested.c: Likewise.

From-SVN: r86457

gcc/ChangeLog
gcc/cfg.c
gcc/function.c
gcc/tree-nested.c

index 0e0cc94fa981e3751ac0c17f927423e7ae3fd30d..0667a1ad998828cee4cf4c435cadcf9fc5d67b82 100644 (file)
@@ -1,3 +1,9 @@
+2004-08-23  Diego Novillo  <dnovillo@redhat.com>
+
+       * cfg.c (check_bb_profile): Fix typos.
+       * function.c (assign_parm_is_stack_parm): Likewise.
+       * tree-nested.c: Likewise.
+
 2004-08-23  Daniel Jacobowitz  <dan@debian.org>
 
        * ggc-zone.c (struc alloc_chunk): Rearrange flag bits and SIZE.
index cee3cf2211c65e2b8df8e632479d8d745dded021..d195b10cd4ead88ecc1010e36449c793c4b7a3ba 100644 (file)
--- a/gcc/cfg.c
+++ b/gcc/cfg.c
@@ -507,13 +507,13 @@ check_bb_profile (basic_block bb, FILE * file)
        sum += EDGE_FREQUENCY (e);
       if (abs (sum - bb->frequency) > 100)
        fprintf (file,
-                "Invalid sum of incomming frequencies %i, should be %i\n",
+                "Invalid sum of incoming frequencies %i, should be %i\n",
                 sum, bb->frequency);
       lsum = 0;
       for (e = bb->pred; e; e = e->pred_next)
        lsum += e->count;
       if (lsum - bb->count > 100 || lsum - bb->count < -100)
-       fprintf (file, "Invalid sum of incomming counts %i, should be %i\n",
+       fprintf (file, "Invalid sum of incoming counts %i, should be %i\n",
                 (int) lsum, (int) bb->count);
     }
 }
index b6f5a79c661346473f70f19941647210364db5ae..2fbc72269de2afbc7176e219ef0e1deeaf874230 100644 (file)
@@ -2340,7 +2340,7 @@ static bool
 assign_parm_is_stack_parm (struct assign_parm_data_all *all,
                           struct assign_parm_data_one *data)
 {
/* Trivially true if we've no incomming register.  */
   if (data->entry_parm == NULL)
     ;
   /* Also true if we're partially in registers and partially not,
index 00dbee988cda75399b2ab8d2ada5e442fe6c73d0..1d7806d23fd7c36b4da0a8a9e3b7dc8e61208f4b 100644 (file)
@@ -55,7 +55,7 @@
 
    The implementation here is much more direct.  Everything that can be
    referenced by an inner function is a member of an explicitly created
-   structure herein called the "nonlocal frame struct".  The incomming
+   structure herein called the "nonlocal frame struct".  The incoming
    static chain for a nested function is a pointer to this struct in 
    the parent.  In this way, we settle on known offsets from a known
    base, and so are decoupled from the logic that places objects in the
@@ -2340,7 +2340,7 @@ static bool
                           struct assign_parm_data_one *data)
 {
-  /* Trivially true if we've no incomming register.  */
+  /* Trivially true if we've no incoming register.  */
   if (data->entry_parm == NULL)
     ;